@@ -199,13 +199,15 @@ class AutoReWrite(object):
                     "early_stopping":True,
                     "num_return_sequences": 5,
                     "no_repeat_ngram_size":5,
-                    "num_beams":7,
-                    "temperature":0.8267410332747904,
-                    "top_p":0.9055557526279095}
+                    "num_beams":8,
+                    "temperature":0.7773100411930902,
+                    "top_p":0.7735368770052764,
+                    "top_k": 100
+                    }
         payload={"config":config,
                  "text": [text]
                  }
-        return self.predict_summary(payload, timeout=600)
+        return self.predict_summary(payload, timeout=1200)
         # pass
 
     def predict_title(self, payload, timeout=600):
